Package: ROTS
Type: Package
Title: Reproducibility-Optimized Test Statistic
Version: 2.4.0
Author: Fatemeh Seyednasrollah, Tomi Suomi, Laura L. Elo
Maintainer: Tomi Suomi <tomi.suomi@utu.fi>
Description: Calculates the Reproducibility-Optimized Test Statistic
        (ROTS) for differential testing in omics data.
biocViews: Software, GeneExpression, DifferentialExpression,
        Microarray, RNASeq, Proteomics, ImmunoOncology
License: GPL (>= 2)
LazyData: yes
LinkingTo: Rcpp
Imports: Rcpp, stats, Biobase, methods, BiocParallel, lme4, survival
Suggests: testthat
Depends: R (>= 3.6)
NeedsCompilation: yes
git_url: https://git.bioconductor.org/packages/ROTS
git_branch: RELEASE_3_23
git_last_commit: a2b5020
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-29 00:19:10 UTC; biocbuild
