# This file was generated by Rcpp::compileAttributes
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

NeedForSpeed1 <- function(D, S, pD, pS, nrow, N, N_len, ssq, B, overlaps, overlaps_P) {
    .Call('ROTS_NeedForSpeed1', PACKAGE = 'ROTS', D, S, pD, pS, nrow, N, N_len, ssq, B, overlaps, overlaps_P)
}

NeedForSpeed2 <- function(D, pD, nrow, N, N_len, B, overlaps, overlaps_P) {
    .Call('ROTS_NeedForSpeed2', PACKAGE = 'ROTS', D, pD, nrow, N, N_len, B, overlaps, overlaps_P)
}

pvalue <- function(a, b) {
    .Call('ROTS_pvalue', PACKAGE = 'ROTS', a, b)
}

